Calibration
===========

.. automodule:: pyelink.calibration
   :members:
   :undoc-members:
   :show-inheritance:

Base Calibration Display
------------------------

.. automodule:: pyelink.calibration.base
   :members:
   :undoc-members:
   :show-inheritance:

Calibration Targets
-------------------

.. automodule:: pyelink.calibration.targets
   :members:
   :undoc-members:
   :show-inheritance:

Pygame Backend
--------------

.. automodule:: pyelink.calibration.pygame_backend
   :members:
   :undoc-members:
   :show-inheritance:

PsychoPy Backend
----------------

.. automodule:: pyelink.calibration.psychopy_backend
   :members:
   :undoc-members:
   :show-inheritance:

Pyglet Backend
--------------

.. automodule:: pyelink.calibration.pyglet_backend
   :members:
   :undoc-members:
   :show-inheritance:
